==> ejc-middlemeasurement-impl-3.0.0-20221012.192032-154-sources.jar: com/ejianc/business/middlemeasurement/bean/VisaclaimCountersignEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 签证索赔会签单主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_visaclaim_countersign")
public class VisaclaimCountersignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="visa_matters")
    private String visaMatters; // 签证事项
    @TableField(value="visa_claims")
    private String visaClaims; // 签证索赔事项
    @TableField(value="agent_id")
    private Long agentId; // 经办人
    @TableField(value="agent_name")
    private String agentName; // 经办人姓名
    @TableField(value="visaclaim_amount")
    private BigDecimal visaclaimAmount; // 签证索赔金额
    @TableField(value="visaclaim_confirmed_amount")
    private BigDecimal visaclaimConfirmedAmount; //  签证索赔确认金额
    @TableField(value="visa_content_and_amount_calculation_process")
    private String visaContentAndAmountCalculationProcess; // 签证内容描述及签证金额计算过程
    @TableField(value="agent_signature")
    private String agentSignature; // 经办人签字
    @TableField(value="agent_date")
    private Date agentDate; // 经办人签字日期
    @TableField(value="opinion_engineer")
    private String opinionEngineer; // 项目总工程师意见
    @TableField(value="engineer_date")
    private Date engineerDate; // 项目总工程师意见日期
    @TableField(value="opinion_project_business_manager")
    private String opinionProjectBusinessManager; // 项目商务经理意见
    @TableField(value="project_business_manager_signature")
    private String projectBusinessManagerSignature; // 项目商务经理签字
    @TableField(value="project_business_manager_date")
    private Date projectBusinessManagerDate; // 项目商务经理签字日期
    @TableField(value="opinion_project_manager")
    private String opinionProjectManager; // 项目经理审核意见
    @TableField(value="project_manager_signature")
    private String projectManagerSignature; // 项目经理签字
    @TableField(value="project_manager_date")
    private Date projectManagerDate; // 项目经理签字日期
    @TableField(value="opinion_business_management_department")
    private String opinionBusinessManagementDepartment; // 分/子公司商务管理部意见
    @TableField(value="business_management_department_signature")
    private String businessManagementDepartmentSignature; // 分/子公司商务管理部签字
    @TableField(value="business_management_department_date")
    private Date businessManagementDepartmentDate; // 分/子公司商务管理部签字日期
    @TableField(value="opinion_company_legal_counsel")
    private String opinionCompanyLegalCounsel; // 分/子公司法律顾问或法务人员意见
    @TableField(value="company_legal_counsel_signature")
    private String companyLegalCounselSignature; // 分/子公司法律顾问或法务人员签字
    @TableField(value="company_legal_counsel_date")
    private Date companyLegalCounselDate; // 分/子公司法律顾问或法务人员签字日期
    @TableField(value="opinion_company_leader")
    private String opinionCompanyLeader; // 分/子公司分管领导意见
    @TableField(value="company_leader_signature")
    private String companyLeaderSignature; // 分/子公司分管领导签字
    @TableField(value="company_leader_date")
    private Date companyLeaderDate; // 分/子公司分管领导签字日期
    @TableField(value="opinion_company_general_manager")
    private String opinionCompanyGeneralManager; // 分/子公司总经理意见
    @TableField(value="company_general_manager_signature")
    private String companyGeneralManagerSignature; // 分/子公司总经理签字
    @TableField(value="company_general_manager_date")
    private Date companyGeneralManagerDate; // 分/子公司总经理签字日期
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getVisaMatters() {
        return visaMatters;
    }

    public void setVisaMatters(String visaMatters) {
        this.visaMatters = visaMatters;
    }
    public String getVisaClaims() {
        return visaClaims;
    }

    public void setVisaClaims(String visaClaims) {
        this.visaClaims = visaClaims;
    }
    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public BigDecimal getVisaclaimAmount() {
        return visaclaimAmount;
    }

    public void setVisaclaimAmount(BigDecimal visaclaimAmount) {
        this.visaclaimAmount = visaclaimAmount;
    }
    public BigDecimal getVisaclaimConfirmedAmount() {
        return visaclaimConfirmedAmount;
    }

    public void setVisaclaimConfirmedAmount(BigDecimal visaclaimConfirmedAmount) {
        this.visaclaimConfirmedAmount = visaclaimConfirmedAmount;
    }
    public String getVisaContentAndAmountCalculationProcess() {
        return visaContentAndAmountCalculationProcess;
    }

    public void setVisaContentAndAmountCalculationProcess(String visaContentAndAmountCalculationProcess) {
        this.visaContentAndAmountCalculationProcess = visaContentAndAmountCalculationProcess;
    }
    public String getAgentSignature() {
        return agentSignature;
    }

    public void setAgentSignature(String agentSignature) {
        this.agentSignature = agentSignature;
    }
    public Date getAgentDate() {
        return agentDate;
    }

    public void setAgentDate(Date agentDate) {
        this.agentDate = agentDate;
    }
    public String getOpinionEngineer() {
        return opinionEngineer;
    }

    public void setOpinionEngineer(String opinionEngineer) {
        this.opinionEngineer = opinionEngineer;
    }
    public Date getEngineerDate() {
        return engineerDate;
    }

    public void setEngineerDate(Date engineerDate) {
        this.engineerDate = engineerDate;
    }
    public String getOpinionProjectBusinessManager() {
        return opinionProjectBusinessManager;
    }

    public void setOpinionProjectBusinessManager(String opinionProjectBusinessManager) {
        this.opinionProjectBusinessManager = opinionProjectBusinessManager;
    }
    public String getProjectBusinessManagerSignature() {
        return projectBusinessManagerSignature;
    }

    public void setProjectBusinessManagerSignature(String projectBusinessManagerSignature) {
        this.projectBusinessManagerSignature = projectBusinessManagerSignature;
    }
    public Date getProjectBusinessManagerDate() {
        return projectBusinessManagerDate;
    }

    public void setProjectBusinessManagerDate(Date projectBusinessManagerDate) {
        this.projectBusinessManagerDate = projectBusinessManagerDate;
    }
    public String getOpinionProjectManager() {
        return opinionProjectManager;
    }

    public void setOpinionProjectManager(String opinionProjectManager) {
        this.opinionProjectManager = opinionProjectManager;
    }
    public String getProjectManagerSignature() {
        return projectManagerSignature;
    }

    public void setProjectManagerSignature(String projectManagerSignature) {
        this.projectManagerSignature = projectManagerSignature;
    }
    public Date getProjectManagerDate() {
        return projectManagerDate;
    }

    public void setProjectManagerDate(Date projectManagerDate) {
        this.projectManagerDate = projectManagerDate;
    }
    public String getOpinionBusinessManagementDepartment() {
        return opinionBusinessManagementDepartment;
    }

    public void setOpinionBusinessManagementDepartment(String opinionBusinessManagementDepartment) {
        this.opinionBusinessManagementDepartment = opinionBusinessManagementDepartment;
    }
    public String getBusinessManagementDepartmentSignature() {
        return businessManagementDepartmentSignature;
    }

    public void setBusinessManagementDepartmentSignature(String businessManagementDepartmentSignature) {
        this.businessManagementDepartmentSignature = businessManagementDepartmentSignature;
    }
    public Date getBusinessManagementDepartmentDate() {
        return businessManagementDepartmentDate;
    }

    public void setBusinessManagementDepartmentDate(Date businessManagementDepartmentDate) {
        this.businessManagementDepartmentDate = businessManagementDepartmentDate;
    }
    public String getOpinionCompanyLegalCounsel() {
        return opinionCompanyLegalCounsel;
    }

    public void setOpinionCompanyLegalCounsel(String opinionCompanyLegalCounsel) {
        this.opinionCompanyLegalCounsel = opinionCompanyLegalCounsel;
    }
    public String getCompanyLegalCounselSignature() {
        return companyLegalCounselSignature;
    }

    public void setCompanyLegalCounselSignature(String companyLegalCounselSignature) {
        this.companyLegalCounselSignature = companyLegalCounselSignature;
    }
    public Date getCompanyLegalCounselDate() {
        return companyLegalCounselDate;
    }

    public void setCompanyLegalCounselDate(Date companyLegalCounselDate) {
        this.companyLegalCounselDate = companyLegalCounselDate;
    }
    public String getOpinionCompanyLeader() {
        return opinionCompanyLeader;
    }

    public void setOpinionCompanyLeader(String opinionCompanyLeader) {
        this.opinionCompanyLeader = opinionCompanyLeader;
    }
    public String getCompanyLeaderSignature() {
        return companyLeaderSignature;
    }

    public void setCompanyLeaderSignature(String companyLeaderSignature) {
        this.companyLeaderSignature = companyLeaderSignature;
    }
    public Date getCompanyLeaderDate() {
        return companyLeaderDate;
    }

    public void setCompanyLeaderDate(Date companyLeaderDate) {
        this.companyLeaderDate = companyLeaderDate;
    }
    public String getOpinionCompanyGeneralManager() {
        return opinionCompanyGeneralManager;
    }

    public void setOpinionCompanyGeneralManager(String opinionCompanyGeneralManager) {
        this.opinionCompanyGeneralManager = opinionCompanyGeneralManager;
    }
    public String getCompanyGeneralManagerSignature() {
        return companyGeneralManagerSignature;
    }

    public void setCompanyGeneralManagerSignature(String companyGeneralManagerSignature) {
        this.companyGeneralManagerSignature = companyGeneralManagerSignature;
    }
    public Date getCompanyGeneralManagerDate() {
        return companyGeneralManagerDate;
    }

    public void setCompanyGeneralManagerDate(Date companyGeneralManagerDate) {
        this.companyGeneralManagerDate = companyGeneralManagerDate;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20241126.022138-621-sources.jar: com/ejianc/business/middlemeasurement/bean/VisaclaimCountersignEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 签证索赔会签单主表
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_visaclaim_countersign")
public class VisaclaimCountersignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="visa_matters")
    private String visaMatters; // 签证事项
    @TableField(value="visa_claims")
    private String visaClaims; // 签证索赔事项
    @TableField(value="agent_id")
    private Long agentId; // 经办人
    @TableField(value="agent_name")
    private String agentName; // 经办人姓名
    @TableField(value="visaclaim_amount")
    private BigDecimal visaclaimAmount; // 签证索赔金额
    @TableField(value="visaclaim_confirmed_amount")
    private BigDecimal visaclaimConfirmedAmount; //  签证索赔确认金额
    @TableField(value="visa_content_and_amount_calculation_process")
    private String visaContentAndAmountCalculationProcess; // 签证内容描述及签证金额计算过程
    @TableField(value="agent_signature")
    private String agentSignature; // 经办人签字
    @TableField(value="agent_date")
    private Date agentDate; // 经办人签字日期
    @TableField(value="opinion_engineer")
    private String opinionEngineer; // 项目总工程师意见
    @TableField(value="engineer_date")
    private Date engineerDate; // 项目总工程师意见日期
    @TableField(value="opinion_project_business_manager")
    private String opinionProjectBusinessManager; // 项目商务经理意见
    @TableField(value="project_business_manager_signature")
    private String projectBusinessManagerSignature; // 项目商务经理签字
    @TableField(value="project_business_manager_date")
    private Date projectBusinessManagerDate; // 项目商务经理签字日期
    @TableField(value="opinion_project_manager")
    private String opinionProjectManager; // 项目经理审核意见
    @TableField(value="project_manager_signature")
    private String projectManagerSignature; // 项目经理签字
    @TableField(value="project_manager_date")
    private Date projectManagerDate; // 项目经理签字日期
    @TableField(value="opinion_business_management_department")
    private String opinionBusinessManagementDepartment; // 分/子公司商务管理部意见
    @TableField(value="business_management_department_signature")
    private String businessManagementDepartmentSignature; // 分/子公司商务管理部签字
    @TableField(value="business_management_department_date")
    private Date businessManagementDepartmentDate; // 分/子公司商务管理部签字日期
    @TableField(value="opinion_company_legal_counsel")
    private String opinionCompanyLegalCounsel; // 分/子公司法律顾问或法务人员意见
    @TableField(value="company_legal_counsel_signature")
    private String companyLegalCounselSignature; // 分/子公司法律顾问或法务人员签字
    @TableField(value="company_legal_counsel_date")
    private Date companyLegalCounselDate; // 分/子公司法律顾问或法务人员签字日期
    @TableField(value="opinion_company_leader")
    private String opinionCompanyLeader; // 分/子公司分管领导意见
    @TableField(value="company_leader_signature")
    private String companyLeaderSignature; // 分/子公司分管领导签字
    @TableField(value="company_leader_date")
    private Date companyLeaderDate; // 分/子公司分管领导签字日期
    @TableField(value="opinion_company_general_manager")
    private String opinionCompanyGeneralManager; // 分/子公司总经理意见
    @TableField(value="company_general_manager_signature")
    private String companyGeneralManagerSignature; // 分/子公司总经理签字
    @TableField(value="company_general_manager_date")
    private Date companyGeneralManagerDate; // 分/子公司总经理签字日期
    @TableField(value="ex_visaclaim_amount")
    private BigDecimal exVisaclaimAmount; // 报送金额(除税)
    @TableField(value="great_claims_flag")
    private Integer greatClaimsFlag; // 是否重大索赔事项
    @TableField(value="affirm_mny_tax")
    private BigDecimal affirmMnyTax; // 确认金额（含税）
    @TableField(value="affirm_mny")
    private BigDecimal affirmMny; // 确认金额（除税）
    @TableField(value="affirm_change_days")
    private BigDecimal affirmChangeDays; // 确认变更天数
    @TableField(value="affirm_time")
    private Date affirmTime; // 确认时间
    @TableField(value="total_mny")
    private BigDecimal totalMny; // 已收款金额
    @TableField(value="claims_days")
    private BigDecimal claimsDays; // 索赔天数

    @TableField(exist = false)
    @SubEntity(serviceName = "visaclaimCountersignDetailService", pidName = "pid")
    private List<VisaclaimCountersignDetailEntity> visaclaimCountersignDetailEntities = new ArrayList<>();




    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getVisaMatters() {
        return visaMatters;
    }

    public void setVisaMatters(String visaMatters) {
        this.visaMatters = visaMatters;
    }
    public String getVisaClaims() {
        return visaClaims;
    }

    public void setVisaClaims(String visaClaims) {
        this.visaClaims = visaClaims;
    }
    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public BigDecimal getVisaclaimAmount() {
        return visaclaimAmount;
    }

    public void setVisaclaimAmount(BigDecimal visaclaimAmount) {
        this.visaclaimAmount = visaclaimAmount;
    }
    public BigDecimal getVisaclaimConfirmedAmount() {
        return visaclaimConfirmedAmount;
    }

    public void setVisaclaimConfirmedAmount(BigDecimal visaclaimConfirmedAmount) {
        this.visaclaimConfirmedAmount = visaclaimConfirmedAmount;
    }
    public String getVisaContentAndAmountCalculationProcess() {
        return visaContentAndAmountCalculationProcess;
    }

    public void setVisaContentAndAmountCalculationProcess(String visaContentAndAmountCalculationProcess) {
        this.visaContentAndAmountCalculationProcess = visaContentAndAmountCalculationProcess;
    }
    public String getAgentSignature() {
        return agentSignature;
    }

    public void setAgentSignature(String agentSignature) {
        this.agentSignature = agentSignature;
    }
    public Date getAgentDate() {
        return agentDate;
    }

    public void setAgentDate(Date agentDate) {
        this.agentDate = agentDate;
    }
    public String getOpinionEngineer() {
        return opinionEngineer;
    }

    public void setOpinionEngineer(String opinionEngineer) {
        this.opinionEngineer = opinionEngineer;
    }
    public Date getEngineerDate() {
        return engineerDate;
    }

    public void setEngineerDate(Date engineerDate) {
        this.engineerDate = engineerDate;
    }
    public String getOpinionProjectBusinessManager() {
        return opinionProjectBusinessManager;
    }

    public void setOpinionProjectBusinessManager(String opinionProjectBusinessManager) {
        this.opinionProjectBusinessManager = opinionProjectBusinessManager;
    }
    public String getProjectBusinessManagerSignature() {
        return projectBusinessManagerSignature;
    }

    public void setProjectBusinessManagerSignature(String projectBusinessManagerSignature) {
        this.projectBusinessManagerSignature = projectBusinessManagerSignature;
    }
    public Date getProjectBusinessManagerDate() {
        return projectBusinessManagerDate;
    }

    public void setProjectBusinessManagerDate(Date projectBusinessManagerDate) {
        this.projectBusinessManagerDate = projectBusinessManagerDate;
    }
    public String getOpinionProjectManager() {
        return opinionProjectManager;
    }

    public void setOpinionProjectManager(String opinionProjectManager) {
        this.opinionProjectManager = opinionProjectManager;
    }
    public String getProjectManagerSignature() {
        return projectManagerSignature;
    }

    public void setProjectManagerSignature(String projectManagerSignature) {
        this.projectManagerSignature = projectManagerSignature;
    }
    public Date getProjectManagerDate() {
        return projectManagerDate;
    }

    public void setProjectManagerDate(Date projectManagerDate) {
        this.projectManagerDate = projectManagerDate;
    }
    public String getOpinionBusinessManagementDepartment() {
        return opinionBusinessManagementDepartment;
    }

    public void setOpinionBusinessManagementDepartment(String opinionBusinessManagementDepartment) {
        this.opinionBusinessManagementDepartment = opinionBusinessManagementDepartment;
    }
    public String getBusinessManagementDepartmentSignature() {
        return businessManagementDepartmentSignature;
    }

    public void setBusinessManagementDepartmentSignature(String businessManagementDepartmentSignature) {
        this.businessManagementDepartmentSignature = businessManagementDepartmentSignature;
    }
    public Date getBusinessManagementDepartmentDate() {
        return businessManagementDepartmentDate;
    }

    public void setBusinessManagementDepartmentDate(Date businessManagementDepartmentDate) {
        this.businessManagementDepartmentDate = businessManagementDepartmentDate;
    }
    public String getOpinionCompanyLegalCounsel() {
        return opinionCompanyLegalCounsel;
    }

    public void setOpinionCompanyLegalCounsel(String opinionCompanyLegalCounsel) {
        this.opinionCompanyLegalCounsel = opinionCompanyLegalCounsel;
    }
    public String getCompanyLegalCounselSignature() {
        return companyLegalCounselSignature;
    }

    public void setCompanyLegalCounselSignature(String companyLegalCounselSignature) {
        this.companyLegalCounselSignature = companyLegalCounselSignature;
    }
    public Date getCompanyLegalCounselDate() {
        return companyLegalCounselDate;
    }

    public void setCompanyLegalCounselDate(Date companyLegalCounselDate) {
        this.companyLegalCounselDate = companyLegalCounselDate;
    }
    public String getOpinionCompanyLeader() {
        return opinionCompanyLeader;
    }

    public void setOpinionCompanyLeader(String opinionCompanyLeader) {
        this.opinionCompanyLeader = opinionCompanyLeader;
    }
    public String getCompanyLeaderSignature() {
        return companyLeaderSignature;
    }

    public void setCompanyLeaderSignature(String companyLeaderSignature) {
        this.companyLeaderSignature = companyLeaderSignature;
    }
    public Date getCompanyLeaderDate() {
        return companyLeaderDate;
    }

    public void setCompanyLeaderDate(Date companyLeaderDate) {
        this.companyLeaderDate = companyLeaderDate;
    }
    public String getOpinionCompanyGeneralManager() {
        return opinionCompanyGeneralManager;
    }

    public void setOpinionCompanyGeneralManager(String opinionCompanyGeneralManager) {
        this.opinionCompanyGeneralManager = opinionCompanyGeneralManager;
    }
    public String getCompanyGeneralManagerSignature() {
        return companyGeneralManagerSignature;
    }

    public void setCompanyGeneralManagerSignature(String companyGeneralManagerSignature) {
        this.companyGeneralManagerSignature = companyGeneralManagerSignature;
    }
    public Date getCompanyGeneralManagerDate() {
        return companyGeneralManagerDate;
    }

    public void setCompanyGeneralManagerDate(Date companyGeneralManagerDate) {
        this.companyGeneralManagerDate = companyGeneralManagerDate;
    }

    public BigDecimal getExVisaclaimAmount() {
        return exVisaclaimAmount;
    }

    public void setExVisaclaimAmount(BigDecimal exVisaclaimAmount) {
        this.exVisaclaimAmount = exVisaclaimAmount;
    }

    public Integer getGreatClaimsFlag() {
        return greatClaimsFlag;
    }

    public void setGreatClaimsFlag(Integer greatClaimsFlag) {
        this.greatClaimsFlag = greatClaimsFlag;
    }

    public BigDecimal getAffirmMnyTax() {
        return affirmMnyTax;
    }

    public void setAffirmMnyTax(BigDecimal affirmMnyTax) {
        this.affirmMnyTax = affirmMnyTax;
    }

    public BigDecimal getAffirmMny() {
        return affirmMny;
    }

    public void setAffirmMny(BigDecimal affirmMny) {
        this.affirmMny = affirmMny;
    }

    public BigDecimal getAffirmChangeDays() {
        return affirmChangeDays;
    }

    public void setAffirmChangeDays(BigDecimal affirmChangeDays) {
        this.affirmChangeDays = affirmChangeDays;
    }

    public Date getAffirmTime() {
        return affirmTime;
    }

    public void setAffirmTime(Date affirmTime) {
        this.affirmTime = affirmTime;
    }

    public List<VisaclaimCountersignDetailEntity> getVisaclaimCountersignDetailEntities() {
        return visaclaimCountersignDetailEntities;
    }

    public void setVisaclaimCountersignDetailEntities(List<VisaclaimCountersignDetailEntity> visaclaimCountersignDetailEntities) {
        this.visaclaimCountersignDetailEntities = visaclaimCountersignDetailEntities;
    }

    public BigDecimal getTotalMny() {
        return totalMny;
    }

    public void setTotalMny(BigDecimal totalMny) {
        this.totalMny = totalMny;
    }

    public BigDecimal getClaimsDays() {
        return claimsDays;
    }

    public void setClaimsDays(BigDecimal claimsDays) {
        this.claimsDays = claimsDays;
    }
}
